Nestimate-package: Nestimate: Network Estimation, Bootstrap, and Higher-Order...

Nestimate-packageR Documentation

Nestimate: Network Estimation, Bootstrap, and Higher-Order Analysis

Description

logo

Estimate, compare, and analyze dynamic and psychological networks using a unified interface. Provides transition network analysis estimation (transition, frequency, co-occurrence, attention-weighted) Saqr et al. (2025) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1145/3706468.3706513")}, psychological network methods (correlation, partial correlation, 'graphical lasso', 'Ising') Saqr, Beck, and Lopez-Pernas (2024) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/978-3-031-54464-4_19")}, and higher-order network methods including higher-order networks, higher-order network embedding, hyper-path anomaly, and multi-order generative model. Supports bootstrap inference, permutation testing, split-half reliability, centrality stability analysis, mixed Markov models, multi-cluster multi-layer networks and clustering.

Author(s)

Maintainer: Mohammed Saqr saqr@saqr.me [copyright holder]

Authors:

See Also

Useful links:


Nestimate documentation built on April 20, 2026, 5:06 p.m.