| extract_initial_probs | R Documentation |
Extract the initial state probability vector from a TNA model object.
extract_initial_probs(model)
model |
A TNA model object or a list containing an 'initial' element. |
Initial probabilities represent the probability of starting a sequence in each state. If the model doesn't have explicit initial probabilities, this function attempts to estimate them from the data or use uniform probabilities.
A named numeric vector of initial state probabilities.
extract_transition_matrix for extracting the transition matrix,
extract_edges for extracting an edge list.
seqs <- data.frame(V1 = c("A","B","A"), V2 = c("B","A","C"), V3 = c("A","C","B"))
net <- build_network(seqs, method = "relative")
init_probs <- extract_initial_probs(net)
print(init_probs)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.