| summary.net_hypa | R Documentation |
Summary Method for net_hypa
## S3 method for class 'net_hypa'
summary(
object,
n = 10L,
type = c("all", "over", "under"),
order_by = c("sig", "freq", "frequency", "ratio", "path"),
...
)
object |
A |
n |
Integer. Maximum number of paths to display per category (default: 10). |
type |
Character. Which anomalies to show: |
order_by |
Character. Ranking used within each anomaly direction:
|
... |
Additional arguments (ignored). |
A data frame with path, observed, expected, ratio, p_tail, and direction columns.
seqs <- list(c("A","B","C"), c("B","C","A"), c("A","C","B"), c("A","B","C"))
hyp <- build_hypa(seqs, k = 2)
summary(hyp)
seqs <- data.frame(
V1 = c("A","B","C","A","B","C","A","B","C","A"),
V2 = c("B","C","A","B","C","A","B","C","A","B"),
V3 = c("C","A","B","C","A","B","C","A","B","C"),
V4 = c("A","B","C","A","B","C","A","B","C","A")
)
hypa <- build_hypa(seqs, k = 2L)
summary(hypa)
summary(hypa, type = "over", n = 5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.